@@ -1,8 +1,8 @@
 package Tests;
 
-use strict;
-use warnings;
-use Tests::Lol::Cat;
+use strict; #this should be removed on parsing
+use warnings; #also removed on parsing
+use Tests::Lol::Cat; #some unexistent modules
 use Tests::Nyan::Cat;
 use Tests::Super::Powers;
 
@@ -10,6 +10,9 @@ use Tests::Super::Powers;
 use Encode qw(encode);
 use Lolez::Lolus #this is a comment and should be removed from parsing
 use Mojo::Base 'Mojolicious';
+use Modulefoo::Lulz "something in quotes";
+use ModuleLol ();
+
 
 1;
 
